Package: analogsea
Title: Interface to 'DigitalOcean'
Description: Provides a set of functions for interacting with the 'DigitalOcean'
    API <https://www.digitalocean.com/>, including creating images, destroying 
    them, rebooting, getting details on regions, and available images.
Version: 1.0.7.2
Authors@R: c(
    person("Scott", "Chamberlain", role = "aut",
        email = "myrmecocystus@gmail.com",
        comment = c(ORCID="0000-0003-1444-9135")),
    person("Hadley", "Wickham", role = "aut", email = "hadley@rstudio.com"),
    person("Winston", "Chang", role = "aut", email = "winston@stdout.org"),
    person("Bob", "Rudis", role = "ctb", email = "bob@rudis.net"),
    person("Bryce", "Mecum", role = "ctb", email = "brycemecum@gmail.com",
           comment = c("ORCID" = "0000-0002-0381-3766")),
    person("Mauricio", "Vargas", role = c("aut", "cre"), email = "mavargas11@uc.cl",
           comment = c(ORCID = "0000-0003-1017-7574")),
    person("RStudio", role = "cph"),
    person("DigitalOcean", role = "cph")
    )
License: Apache License (>= 2)
URL: https://github.com/pachadotdev/analogsea (devel)
        https://pacha.dev/analogsea/ (docs)
BugReports: https://github.com/pachadotdev/analogsea/issues
Encoding: UTF-8
Language: en-US
Imports: stats, utils, httr (>= 1.2.0), jsonlite (>= 1.1), magrittr,
        yaml
Suggests: testthat, knitr, ssh (>= 0.6), aws.s3, arrow
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-04-19 19:23:30 UTC; pacha
Author: Scott Chamberlain [aut] (<https://orcid.org/0000-0003-1444-9135>),
  Hadley Wickham [aut],
  Winston Chang [aut],
  Bob Rudis [ctb],
  Bryce Mecum [ctb] (<https://orcid.org/0000-0002-0381-3766>),
  Mauricio Vargas [aut, cre] (<https://orcid.org/0000-0003-1017-7574>),
  RStudio [cph],
  DigitalOcean [cph]
Maintainer: Mauricio Vargas <mavargas11@uc.cl>
Repository: CRAN
Date/Publication: 2023-04-19 19:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 05:32:03 UTC; unix
