# Generated by roxygen2: do not edit by hand

S3method(as.action,action)
S3method(as.action,list)
S3method(as.certificate,certificate)
S3method(as.certificate,character)
S3method(as.certificate,list)
S3method(as.character,space)
S3method(as.domain,character)
S3method(as.domain,domain)
S3method(as.domain,list)
S3method(as.domain_record,domain_record)
S3method(as.domain_record,list)
S3method(as.droplet,action)
S3method(as.droplet,character)
S3method(as.droplet,droplet)
S3method(as.droplet,numeric)
S3method(as.firewall,character)
S3method(as.firewall,firewall)
S3method(as.firewall,list)
S3method(as.image,character)
S3method(as.image,image)
S3method(as.image,list)
S3method(as.image,numeric)
S3method(as.project,character)
S3method(as.project,list)
S3method(as.project,numeric)
S3method(as.project,project)
S3method(as.snapshot,character)
S3method(as.snapshot,list)
S3method(as.snapshot,numeric)
S3method(as.snapshot,snapshot)
S3method(as.space,character)
S3method(as.space,space)
S3method(as.sshkey,character)
S3method(as.sshkey,list)
S3method(as.sshkey,numeric)
S3method(as.sshkey,sshkey)
S3method(as.tag,character)
S3method(as.tag,list)
S3method(as.tag,tag)
S3method(as.url,action)
S3method(as.url,certificate)
S3method(as.url,character)
S3method(as.url,do_url)
S3method(as.url,domain)
S3method(as.url,domain_record)
S3method(as.url,firewall)
S3method(as.url,image)
S3method(as.url,project)
S3method(as.url,sshkey)
S3method(as.volume,character)
S3method(as.volume,list)
S3method(as.volume,numeric)
S3method(as.volume,volume)
S3method(print,account)
S3method(print,action)
S3method(print,certificate)
S3method(print,do_rate)
S3method(print,do_url)
S3method(print,domain)
S3method(print,domain_record)
S3method(print,droplet)
S3method(print,firewall)
S3method(print,image)
S3method(print,project)
S3method(print,snapshot)
S3method(print,space)
S3method(print,sshkey)
S3method(print,tag)
S3method(print,volume)
S3method(print,volume_snapshot)
S3method(summary,droplet)
S3method(summary,space)
export("%>%")
export(account)
export(action)
export(action_wait)
export(actions)
export(as.certificate)
export(as.domain)
export(as.domain_record)
export(as.droplet)
export(as.firewall)
export(as.image)
export(as.project)
export(as.snapshot)
export(as.space)
export(as.sshkey)
export(as.tag)
export(as.volume)
export(certificate)
export(certificate_create)
export(certificate_delete)
export(certificates)
export(cloud_config)
export(create_password)
export(databases)
export(debian_add_swap)
export(debian_apt_get_install)
export(debian_apt_get_update)
export(debian_install_r)
export(debian_install_rstudio)
export(debian_install_shiny)
export(do_DELETE)
export(do_DELETE_body)
export(do_GET)
export(do_PATCH)
export(do_POST)
export(do_PUT)
export(do_oauth)
export(do_options)
export(docklet_create)
export(docklet_docker)
export(docklet_images)
export(docklet_ps)
export(docklet_pull)
export(docklet_rm)
export(docklet_rstudio)
export(docklet_rstudio_addusers)
export(docklet_run)
export(docklet_shinyapp)
export(docklet_shinyserver)
export(docklet_stop)
export(docklets_create)
export(domain)
export(domain_create)
export(domain_delete)
export(domain_record)
export(domain_record_create)
export(domain_record_delete)
export(domain_record_update)
export(domain_records)
export(domains)
export(droplet)
export(droplet_actions)
export(droplet_backups_list)
export(droplet_change_kernel)
export(droplet_create)
export(droplet_delete)
export(droplet_disable_backups)
export(droplet_do_actions)
export(droplet_download)
export(droplet_enable_backups)
export(droplet_enable_ipv6)
export(droplet_enable_private_networking)
export(droplet_execute)
export(droplet_freeze)
export(droplet_ip)
export(droplet_kernels_list)
export(droplet_neighbors)
export(droplet_power_cycle)
export(droplet_power_off)
export(droplet_power_on)
export(droplet_reboot)
export(droplet_rebuild)
export(droplet_rename)
export(droplet_reset_password)
export(droplet_resize)
export(droplet_restore)
export(droplet_reuse)
export(droplet_shutdown)
export(droplet_snapshot)
export(droplet_snapshots_list)
export(droplet_ssh)
export(droplet_thaw)
export(droplet_upgrade)
export(droplet_upgrades_list)
export(droplet_upload)
export(droplet_wait)
export(droplets)
export(droplets_cost)
export(droplets_create)
export(firewall)
export(firewall_add_droplets)
export(firewall_add_tags)
export(firewall_create)
export(firewall_delete)
export(firewall_remove_droplets)
export(firewall_remove_tags)
export(firewall_update)
export(firewalls)
export(image)
export(image_actions)
export(image_convert)
export(image_delete)
export(image_rename)
export(image_transfer)
export(images)
export(install_github_r_package)
export(install_r_package)
export(key)
export(key_create)
export(key_delete)
export(key_rename)
export(keys)
export(neighbors)
export(project)
export(project_create)
export(project_delete)
export(project_patch)
export(project_update)
export(projects)
export(rate_limit)
export(regions)
export(resize)
export(sizes)
export(snapshot)
export(snapshot_delete)
export(snapshots)
export(space_create)
export(space_delete)
export(space_download)
export(space_upload)
export(spaces)
export(standardise_keys)
export(tag)
export(tag_create)
export(tag_delete)
export(tag_rename)
export(tag_resource)
export(tag_resource_delete)
export(tags)
export(ubuntu_add_swap)
export(ubuntu_apt_get_cran)
export(ubuntu_apt_get_install)
export(ubuntu_apt_get_update)
export(ubuntu_create_user)
export(ubuntu_install_r)
export(ubuntu_install_rstudio)
export(ubuntu_install_shiny)
export(volume)
export(volume_action)
export(volume_actions)
export(volume_attach)
export(volume_create)
export(volume_delete)
export(volume_detach)
export(volume_resize)
export(volume_snapshot_create)
export(volume_snapshots)
export(volumes)
importFrom(httr,GET)
importFrom(httr,HEAD)
importFrom(httr,POST)
importFrom(httr,VERB)
importFrom(httr,add_headers)
importFrom(httr,config)
importFrom(httr,content)
importFrom(httr,headers)
importFrom(httr,oauth2.0_token)
importFrom(httr,oauth_app)
importFrom(httr,oauth_endpoint)
importFrom(httr,status_code)
importFrom(httr,stop_for_status)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,unbox)
importFrom(magrittr,"%>%")
importFrom(stats,setNames)
importFrom(utils,browseURL)
importFrom(utils,read.csv)
importFrom(yaml,as.yaml)
importFrom(yaml,yaml.load_file)
